@@ -1895,18 +1895,15 @@ void DynsymSection<E>::update_shdr(Context<E> &ctx) {
 
 template <typename E>
 void DynsymSection<E>::copy_buf(Context<E> &ctx) {
-  u8 *base = ctx.buf + this->shdr.sh_offset;
-  memset(base, 0, sizeof(ElfSym<E>));
+  ElfSym<E> *buf = (ElfSym<E> *)(ctx.buf + this->shdr.sh_offset);
   i64 name_offset = ctx.dynstr->dynsym_offset;
 
+  memset(buf, 0, sizeof(ElfSym<E>));
+
   for (i64 i = 1; i < symbols.size(); i++) {
     Symbol<E> &sym = *symbols[i];
-    ElfSym<E> &esym =
-      *(ElfSym<E> *)(base + sym.get_dynsym_idx(ctx) * sizeof(ElfSym<E>));
-
-    esym = to_output_esym(ctx, sym, name_offset, nullptr);
+    buf[sym.get_dynsym_idx(ctx)] = to_output_esym(ctx, sym, name_offset, nullptr);
     name_offset += sym.name().size() + 1;
-    assert(esym.st_bind != STB_LOCAL || i < this->shdr.sh_info);
   }
 }
 
@@ -1931,17 +1928,14 @@ void HashSection<E>::copy_buf(Context<E> &ctx) {
   Entry *buckets = hdr + 2;
   Entry *chains = buckets + syms.size();
 
-  hdr[0] = hdr[1] = syms.size();
+  hdr[0] = syms.size();
+  hdr[1] = syms.size();
 
-  std::vector<u32> hashes(syms.size());
-  tbb::parallel_for((i64)1, (i64)syms.size(), [&](i64 i) {
-    hashes[i] = elf_hash(syms[i]->name()) % syms.size();
-  });
-
-  for (i64 i = 1; i < syms.size(); i++) {
-    i64 h = hashes[i];
-    chains[syms[i]->get_dynsym_idx(ctx)] = buckets[h];
-    buckets[h] = syms[i]->get_dynsym_idx(ctx);
+  for (Symbol<E> *sym : syms.subspan(1)) {
+    i64 i = sym->get_dynsym_idx(ctx);
+    i64 h = elf_hash(sym->name()) % syms.size();
+    chains[i] = buckets[h];
+    buckets[h] = i;
   }
 }
 
